@@ -40,7 +40,7 @@ Provide a usage message.
 
 =item B<-d>, B<--data-dir> I<DIR>
 
-Choose data directory (default: F<$HOME/.chdist/>).
+Choose data directory (default: F<~/.chdist/>).
 
 =item B<-a>, B<--arch> I<ARCH>
 
@@ -80,6 +80,10 @@ Run B<apt-file> inside I<DIST>
 
 Run B<apt-rdepends> inside I<DIST>
 
+=item B<aptitude> I<DIST> [...]
+
+Run B<aptitude> inside I<DIST>
+
 =item B<src2bin> I<DIST SRCPKG>
 
 List binary packages for I<SRCPKG> in I<DIST>
@@ -139,6 +143,7 @@ use warnings;
 no if $] >= 5.018, 'warnings', 'experimental::smartmatch';
 use feature 'switch';
 use File::Copy qw(cp);
+use File::HomeDir;
 use File::Path qw(make_path);
 use File::Basename;
 use Getopt::Long qw(:config gnu_compat bundling require_order);
@@ -177,7 +182,7 @@ License, version 2 or (at your option) any later version.
 EOF
 
 my $arch;
-my $datadir = $ENV{'HOME'} . '/.chdist';
+my $datadir = File::HomeDir->my_home . '/.chdist';
 
 GetOptions(
   "h|help"       => \$help,
@@ -470,8 +475,15 @@ sub dist_compare(\@$$) {
      foreach my $file ( @files ) {
         my $parsed_file = parseFile($file);
         foreach my $package ( keys(%{$parsed_file}) ) {
-           if ( $packages{$dist}{$package} ) {
-              warn "W: Package $package is already listed for $dist. Not overriding.\n";
+           if ($packages{$dist}{$package}) {
+              my $version = $packages{$dist}{$package}{Version};
+              my $alt_ver = $parsed_file->{$package}{Version};
+              my $delta = $version && $alt_ver && version_compare($version, $alt_ver);
+              if (defined($delta) && $delta < 0) {
+                 $packages{$dist}{$package} = $parsed_file->{$package};
+              } else {
+                 warn "W: Package $package is already listed for $dist. Not overriding.\n";
+              }
            } else {
               $packages{$dist}{$package} = $parsed_file->{$package};
            }
@@ -500,7 +512,7 @@ sub dist_compare(\@$$) {
      # Escaped versions
      my @esc_vers = @versions;
      foreach my $vers (@esc_vers) {
-        $vers =~ s|\+|\\\+|;
+        $vers =~ s|\+|\\\+| if defined $vers;
      }
 
      # Do compare
@@ -585,7 +597,7 @@ sub compare_src_bin {
     foreach my $package (@all_packages) {
 	my $line = "$package ";
 	my $status = "";
-	my $details;
+	my $details = '';
 
 	foreach my $type (@comp_types) {
 	    if ( $packages{$type}{$package} ) {
@@ -718,6 +730,9 @@ given ($command) {
     when ('apt-rdepends') {
 	aptcmd('apt-rdepends', @ARGV);
     }
+    when ('aptitude') {
+	aptcmd('aptitude', @ARGV);
+    }
     when ('bin2src') {
 	bin2src(@ARGV);
     }
