@@ -182,9 +182,10 @@ options to "bzr commit" will be generated to associate the revision and the bugs
 
 use warnings;
 use strict;
-use Getopt::Long qw(:config gnu_getopt);
+use Getopt::Long qw(:config bundling permute no_getopt_compat);
 use Cwd;
 use File::Basename;
+use File::HomeDir;
 use File::Temp;
 my $progname = basename($0);
 
@@ -460,7 +461,7 @@ sub getprog {
     }
 
     # Test for this file to avoid interactive prompting from svk.
-    if (-d "$ENV{HOME}/.svk/local") {
+    if (-d File::HomeDir->my_home."/.svk/local") {
 	# svk has no useful directories so try to run it.
 	my $svkpath=`svk info . 2>/dev/null| grep -i '^Depot Path:' | cut -d ' ' -f 3`;
 	if (length $svkpath) {
@@ -700,8 +701,8 @@ sub tag {
 	}
     }
     elsif ($prog eq 'git') {
-	$tag =~ s/^[0-9]+://; # strip epoch
-	$tag =~ tr/~/./; # mangle for git
+	$tag =~ tr/~/_/; # mangle for git
+	$tag =~ tr/:/%/;
 	if ($tag =~ /-/) {
 	    # not a native package, so tag as a debian release
 	    $tag = "debian/$tag";
