@@ -34,7 +34,7 @@ use IO::File;
 use Digest::MD5;
 use Devscripts::Compression;
 use Dpkg::Control;
-use Getopt::Long qw(:config gnu_getopt);
+use Getopt::Long qw(:config bundling permute no_getopt_compat);
 use File::Basename;
 
 # global variables
@@ -280,7 +280,7 @@ sub apt_get {
 	    $version = $1;
 	    $qversion = quote_version($version);
 	}
-	if ($qversion and /^ [ *]{3} ($qversion) 0/) {
+	if ($qversion and /^ [ *]{3} ($qversion) \d/) {
 	    while (<$apt>) {
 		last OUTER unless /^  *(?:\d+) (\S+)/;
 		(my $host = $1) =~ s@/$@@;
@@ -333,23 +333,22 @@ sub apt_get {
     my %repositories;
     # the regexp within the map below can be removed and replaced with only the quotemeta statement once bug #154868 is fixed
     my $host_re = '(?:' . (join '|', map { my $host = quotemeta; $host =~ s@^(\w+\\:\\/\\/[^:/]+)\\/@$1(?::[0-9]+)?\\/@; $host; } @hosts) . ')';
+
+    my @sources;
     if (-f "/etc/apt/sources.list") {
-	$apt = new IO::File("/etc/apt/sources.list") or die "/etc/apt/sources.list: $!";
-	while (<$apt>) {
-	    if (/^\s*deb\s*($host_re\b)/) {
-		$repositories{$1} = 1;
-	    }
-	}
-	close $apt;
+	push @sources, "/etc/apt/sources.list";
     }
     my %dir;
     tie %dir, "IO::Dir", "/etc/apt/sources.list.d";
     foreach (keys %dir) {
 	next unless /\.list$/;
-	$_ = "/etc/apt/sources.list.d/$_";
-	$apt = new IO::File("$_") or die "$_: $!";
+	push @sources, "/etc/apt/sources.list.d/$_";
+    }
+
+    foreach my $source (@sources) {
+	$apt = IO::File->new($source) or die "$source: $!";
 	while (<$apt>) {
-	    if (/^\s*deb\s*($host_re\b)/) {
+	    if (/^\s*deb\s*(?:\[[^]]*\]\s*)?($host_re\b)/) {
 		$repositories{$1} = 1;
 	    }
 	}
@@ -458,7 +457,7 @@ for my $arg (@ARGV) {
     $found_dsc = "";
 
     # case 1: URL
-    if ($arg =~ /^((?:copy|file|ftp|http|rsh|rsync|ssh|www).*)\/([^\/]+\.\w+)$/) {
+    if ($arg =~ /^((?:copy|file|ftp|gopher|http|rsh|rsync|ssh|www).*)\/([^\/]+\.\w+)$/) {
 	get_file($1, $2, "unlink") or exit 1;
 	if ($found_dsc) {
 	    if ($dget_verify) { # We are duplicating work here a bit as
@@ -471,16 +470,19 @@ for my $arg (@ARGV) {
 	    push @cmd, '--no-check' unless $dget_verify;
 	    if ($opt->{'build'}) {
 		my @output = `LC_ALL=C @cmd $found_dsc`;
+		my $rc = $?;
 		print @output unless $opt->{'quiet'};
+		exit $rc >> 8 if $rc >> 8 != 0;
 		foreach (@output) {
 		    if ( /^dpkg-source: (?:info: )?extracting .* in (.*)/ ) {
 			chdir $1;
-			system 'dpkg-buildpackage', '-b', '-uc';
-			last;
+			exec 'dpkg-buildpackage', '-b', '-uc';
+			die "Unable to run dpkg-buildpackage: $!";
 		    }
 		}
 	    } elsif ($dget_unpack) {
 		system @cmd, $found_dsc;
+		exit $? >> 8 if $? >> 8 != 0;
 	    }
 	}
 
